@@ -1,6 +1,6 @@
 """hyper user commands"""
 import typer
-from hypercli import C3
+from hypercli import HyperCLI
 from .output import output, spinner
 
 app = typer.Typer(help="User account commands")
@@ -13,7 +13,7 @@ def user_info(
 ):
     """Get current user info"""
     if ctx.invoked_subcommand is None:
-        client = C3()
+        client = HyperCLI()
         with spinner("Fetching user info..."):
             user = client.user.get()
         output(user, fmt)
